==> jc-1.4.0.tar.gz: soot/jimple/internal/JLengthExpr.h <==
// public class soot.jimple.internal.JLengthExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d3526440663c1839 soot_jimple_internal_AbstractLengthExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr
// @dep_class 8cc2d5c5c24bed80 soot_jimple_internal_JLengthExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractLengthExpr

#include "soot/jimple/internal/AbstractLengthExpr.h"

#ifndef _JC_soot_jimple_internal_JLengthExpr_H_
#define _JC_soot_jimple_internal_JLengthExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JLengthExpr$sub_refs	_jc_soot_jimple_internal_JLengthExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JLengthExpr$sub_nonrefs	_jc_soot_jimple_internal_JLengthExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JLengthExpr$refs	_jc_soot_jimple_internal_JLengthExpr$refs;
typedef struct _jc_soot_jimple_internal_JLengthExpr$nonrefs	_jc_soot_jimple_internal_JLengthExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JLengthExpr$object	_jc_soot_jimple_internal_JLengthExpr$object;

typedef const struct _jc_soot_jimple_internal_JLengthExpr$vmethods	_jc_soot_jimple_internal_JLengthExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JLengthExpr$vtable	_jc_soot_jimple_internal_JLengthExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JLengthExpr$vtype	_jc_soot_jimple_internal_JLengthExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JLengthExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JLengthExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *);
extern void _jc_soot_jimple_internal_JLengthExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JLengthExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JLengthExpr$method_info$convertToBaf$0357e46cf55b475a;

// Virtual methods structure
struct _jc_soot_jimple_internal_JLengthExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *);
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_JLengthExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractLengthExpr$vmethods	soot_jimple_internal_AbstractLengthExpr;
	_jc_soot_jimple_internal_JLengthExpr$vmethods	soot_jimple_internal_JLengthExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JLengthExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JLengthExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JLengthExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JLengthExpr$refs {
    _jc_soot_jimple_internal_JLengthExpr$sub_refs	soot_jimple_internal_JLengthExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_refs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JLengthExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JLengthExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_nonrefs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_jimple_internal_JLengthExpr$sub_nonrefs	soot_jimple_internal_JLengthExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JLengthExpr$object {
	_jc_soot_jimple_internal_JLengthExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JLengthExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JLengthExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JLengthExpr$vtype _jc_soot_jimple_internal_JLengthExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JLengthExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JLengthExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JLengthExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JLengthExpr.h <==
// public class soot.jimple.internal.JLengthExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d3526440663c1839 soot_jimple_internal_AbstractLengthExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr
// @dep_class 8cc2d5c5c24bed80 soot_jimple_internal_JLengthExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractLengthExpr

#include "soot/jimple/internal/AbstractLengthExpr.h"

#ifndef _JC_soot_jimple_internal_JLengthExpr_H_
#define _JC_soot_jimple_internal_JLengthExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JLengthExpr$sub_refs	_jc_soot_jimple_internal_JLengthExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JLengthExpr$sub_nonrefs	_jc_soot_jimple_internal_JLengthExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JLengthExpr$refs	_jc_soot_jimple_internal_JLengthExpr$refs;
typedef struct _jc_soot_jimple_internal_JLengthExpr$nonrefs	_jc_soot_jimple_internal_JLengthExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JLengthExpr$object	_jc_soot_jimple_internal_JLengthExpr$object;

typedef const struct _jc_soot_jimple_internal_JLengthExpr$vmethods	_jc_soot_jimple_internal_JLengthExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JLengthExpr$vtable	_jc_soot_jimple_internal_JLengthExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JLengthExpr$vtype	_jc_soot_jimple_internal_JLengthExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JLengthExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JLengthExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JLengthExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JLengthExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JLengthExpr$method_info$convertToBaf$0357e46cf55b475a;

// Virtual methods structure
struct _jc_soot_jimple_internal_JLengthExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *) _JC_JCNI_ATTR;
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JLengthExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JLengthExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractLengthExpr$vmethods	soot_jimple_internal_AbstractLengthExpr;
	_jc_soot_jimple_internal_JLengthExpr$vmethods	soot_jimple_internal_JLengthExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JLengthExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JLengthExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JLengthExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JLengthExpr$refs {
    _jc_soot_jimple_internal_JLengthExpr$sub_refs	soot_jimple_internal_JLengthExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_refs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JLengthExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JLengthExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_nonrefs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_jimple_internal_JLengthExpr$sub_nonrefs	soot_jimple_internal_JLengthExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JLengthExpr$object {
	_jc_soot_jimple_internal_JLengthExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JLengthExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JLengthExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JLengthExpr$vtype _jc_soot_jimple_internal_JLengthExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JLengthExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JLengthExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JLengthExpr_H_ */
